@@ -4,7 +4,7 @@ class Endpoints:
     Agents = BASE + "agents"
     Buddies = BASE + "buddies"
     Bundles = BASE + "bundles"
-    Content_Tiers = BASE + "contenttiers"
+    ContentTiers = BASE + "contenttiers"
     Currencies = BASE + "currencies"
     GameMode = BASE + "gamemodes"
     GamemodeEquippables = GameMode + "/equippables"
@@ -21,3 +21,5 @@ class Endpoints:
     WeaponSkins = Weapons + "/skins"
     WeaponSkinChromas = Weapons + "/skinchromas"
     WeaponSkinLevels = Weapons + "/skinlevels"
+    Contracts = BASE + "contracts"
+    Events = BASE + "events"
