@@ -1,6 +1,8 @@
+from dataclasses import dataclass
 from typing import Optional
 
 
+@dataclass
 class PlayerCard:
     uuid: str
     display_name: str
@@ -24,6 +26,3 @@ class PlayerCard:
         self.large_art = data.get("largeArt")
         self.asset_path = data.get("assetPath")
         self.raw_data = data
-
-    def __str__(self):
-        return str(self.raw_data)
