@@ -1,3 +1,7 @@
+from dataclasses import dataclass
+
+
+@dataclass
 class PlayerTitle:
     uuid: str
     display_name: str
